Python CLI application to calculate and animate waves in 1D and 2D, using the weak formulation of the wave equation and the finite element method to numerically calculate the solution for any user-defined continuous function.

examples and docs are located in my github repo! https://github.com/LocoForHotcocoa/fem
